%bcond_without ruby
%define libsepolver 3.5-1

Summary:       SELinux library and simple utilities
Name:          libselinux
Version:       3.5
Release:       4%{?dist}
License:       Public Domain
Url:           https://github.com/SELinuxProject/selinux
Source0:       https://github.com/SELinuxProject/selinux/releases/download/%{version}/libselinux-%{version}.tar.gz
BuildRequires: gcc, make
%if %{with ruby}
BuildRequires: ruby-devel,ruby
%endif
BuildRequires: python3, python3-devel, python3-setuptools, python3-pip, python3-wheel
BuildRequires: swig, pcre2-devel, xz-devel, systemd, libsepol-static >= %{libsepolver}
Requires:      libsepol >= %{libsepolver}, pcre2

%description
Libselinux provides interfaces for SELinux applications to get and set
the security contexts of process and files in order to enhance the security
of current environment.

%package utils
Summary:       SELinux libselinux utilities
Requires:      %{name} = %{version}-%{release}

%description utils
This package provides the utilities which can be used with selinux.

%package -n python3-libselinux
Summary:       SELinux python 3 bindings for libselinux
Requires:      %{name} = %{version}-%{release}
Provides:      %{name}-python3 = %{version}-%{release}

%description -n python3-libselinux
This package provides python3 bindings for developing SELinux applications.

%if %{with ruby}
%package ruby
Summary:       SELinux ruby bindings for libselinux
Requires:      %{name} = %{version}-%{release}
Provides:      ruby(selinux)

%description ruby
This package provides the ruby bindings for developing SELinux applications.
%endif

%package devel
Summary:       Header files and libraries used to build SELinux
Requires:      %{name} = %{version}-%{release}
Requires:      libsepol-devel >= 3.3-1

%description devel
This package provides the libraries and header files for developers
of SELinux applications.

%package static
Summary:       Static libraries used to build SELinux
Requires:      %{name}-devel = %{version}-%{release}

%description static
This package provides the static libraries for developers of
SELinux applications. 

%prep
%setup -q

%build
export DISABLE_RPM="y"
export USE_PCRE2="y"
export CFLAGS="$RPM_OPT_FLAGS -fno-semantic-interposition"

%make_build LIBDIR="%{_libdir}" swigify
%make_build LIBDIR="%{_libdir}" all
%make_build PYTHON=%{__python3} LIBDIR="%{_libdir}" pywrap

%if %{with ruby}
%make_build SHLIBDIR="%{_libdir}" LIBDIR="%{_libdir}" rubywrap
%endif

%install
rm -rf %{buildroot}
install -d %{buildroot}%{_tmpfilesdir}
install -d %{buildroot}%{_rundir}/setrans
echo "d %{_rundir}/setrans 0755 root root" > %{buildroot}%{_tmpfilesdir}/libselinux.conf

make DESTDIR="%{buildroot}" LIBDIR="%{_libdir}" SHLIBDIR="%{_lib}" BINDIR="%{_bindir}" install-pywrap
%make_install LIBDIR="%{_libdir}" SHLIBDIR="%{_libdir}" BINDIR="%{_bindir}"

%if %{with ruby}
make DESTDIR="%{buildroot}" RUBYINSTALL=%{ruby_vendorarchdir} install-rubywrap
%endif

rm -f %{buildroot}%{_sbindir}/{compute_*,deftype,execcon,getenforcemode,getfilecon}
rm -f %{buildroot}%{_sbindir}/{getpidcon,mkdircon,policyvers,setfilecon,selinuxconfig}
rm -f %{buildroot}%{_sbindir}/{selinuxdisable,getseuser,togglesebool,selinux_check_securetty_context}
mv %{buildroot}%{_sbindir}/getdefaultcon %{buildroot}%{_sbindir}/selinuxdefcon
mv %{buildroot}%{_sbindir}/getconlist %{buildroot}%{_sbindir}/selinuxconlist
install -d %{buildroot}%{_mandir}/man8/
rm -f %{buildroot}%{_mandir}/man8/togglesebool*

%files
%license LICENSE
%{_libdir}/libselinux.so.*
%dir %{_rundir}/setrans/
%{_tmpfilesdir}/libselinux.conf

%files utils
%{_sbindir}/*
%{_mandir}/man5/*
%{_mandir}/man8/*
%{_mandir}/ru/man5/*
%{_mandir}/ru/man8/*

%files -n python3-libselinux
%{python3_sitearch}/selinux/
%{python3_sitearch}/selinux-%{version}*
%{python3_sitearch}/_selinux*

%if %{with ruby}
%files ruby
%{ruby_vendorarchdir}/selinux.so
%endif

%files devel
%{_libdir}/libselinux.so
%{_libdir}/pkgconfig/libselinux.pc
%{_includedir}/selinux/
%{_mandir}/man3/*

%files static
%{_libdir}/libselinux.a

%changelog
* Wed Jan 31 2024 Wang Guodong <gordonwwang@tencent.com> - 3.5-4
- Fix build with pip 23.1+

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.5-3
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.5-2
- Rebuilt for OpenCloudOS Stream 23.09

* Tue Jul 11 2023 Yi Lin <nilusyi@tencent.com> - 3.5-1
- upgrade to 3.5

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.4-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.4-2
- Rebuilt for OpenCloudOS Stream 23

* Wed Jun 29 2022 cunshunxia <cunshunxia@tencent.com> - 3.4-1
- initial build
